import AuthenticatedLayout from "@/Layouts/AuthenticatedLayout";
import { Head, router } from "@inertiajs/react";
import { usePage } from "@inertiajs/react";
import { columns } from "./Column";
import { PaginatedData, AdUnits } from "@/types";
import { DataTable } from "@/Components/DataTable";
import { Input } from "@/Components/ui/input";
import { useCallback, useState } from "react";
import { useSearchParam } from "react-use";
import { PageProps } from "@/types";
import { ChangeEvent } from "react";
import {
    Select,
    SelectContent,
    SelectItem,
    SelectTrigger,
    SelectValue,
} from "@/Components/ui/select";

interface LocalPageProps extends PageProps {
    adUnits: PaginatedData<AdUnits>;
}

export default function Index() {
    const { adUnits } = usePage<LocalPageProps>().props;

    const dateRanges = [
        { value: "TODAY" },
        { value: "YESTERDAY" },
        { value: "LAST_WEEK" },
        { value: "LAST_MONTH" },
        { value: "LAST_3_MONTHS" },
        { value: "REACH_LIFETIME" },
    ];
    const params = useSearchParam("search");

    const [originParam, setOriginParam] = useState(params ?? "");

    const searchSites = useCallback(
        (e: ChangeEvent<HTMLInputElement>) => {
            setOriginParam(e.target.value);
            // const currentRoute = route().current();
            const lineitem = route().params.lineitem; // Get lineitem name dynamically
            const currentRoute = route("group.by.lineitem", { lineitem });
            const search = new URLSearchParams(window.location.search).get('search');
            const dateRange = new URLSearchParams(window.location.search).get(
                "date_range"
            );
            const request: { search?: string; date_range?: string | null } = {};
            if (e.target.value) {
                request.search = e.target.value;
            }
            if (dateRange) {
                request.date_range = dateRange;
            }

            if (currentRoute) {
                router.get(
                    currentRoute,
                    {
                        search: e.target.value,
                        date_range: dateRange,
                    },
                    {
                        replace: true,
                        preserveState: true,
                    }
                );
            } else {
                // Handle the case where the current route is undefined (fallback to a default route or show an error)
                console.error("Current route is undefined");
            }
        },
        [originParam]
    );
    return (
        <AuthenticatedLayout>
            <Head title="Line Item Detail" />

            <div className="bg-white shadow-md rounded px-8 pt-6 pb-8 m-5">
                <h4 className="text-2xl font-bold text-gray-800">
                    Overview of <span className="text-red-500">{route().params.lineitem}</span> line item
                </h4>
                <p className="text-gray-500 text-sm mt-1">
                    Manage your ad units and view performance metrics
                </p>
            </div>
            <div className="bg-white shadow-md rounded px-8 pt-6 pb-8 m-5">
                <div className={"flex justify-between  p-3"}>
                    <div className={"pb-5 text-2xl font-bold"}>
                        <strong>Line Item Detail</strong>
                    </div>
                    <div>
                        <div className={"flex mx-4 gap-2"}>
                            <Select
                                onValueChange={(value) => {
                                    // const currentRoute = route().current();
                                    const lineitem = route().params.lineitem; // Get lineitem name dynamically
                                    const currentRoute = route(
                                        "group.by.lineitem",
                                        { lineitem }
                                    );
                                    if (currentRoute) {
                                        router.get(
                                            currentRoute,
                                            {
                                                search: originParam,
                                                date_range: value,
                                            },
                                            {
                                                replace: true,
                                                preserveState: true,
                                            }
                                        );
                                    }
                                }}
                            >
                                <SelectTrigger className="w-[180px]">
                                    <SelectValue placeholder="Select Date Range" />
                                </SelectTrigger>
                                <SelectContent>
                                    {dateRanges.map((item) => (
                                        <SelectItem
                                            key={item.value}
                                            value={item.value}
                                        >
                                            {item.value}
                                        </SelectItem>
                                    ))}
                                </SelectContent>
                            </Select>

                            <Input
                                placeholder={"Search"}
                                onChange={searchSites}
                                value={originParam}
                            ></Input>
                        </div>
                    </div>
                </div>
                <DataTable columns={columns} data={adUnits.data} />
            </div>
        </AuthenticatedLayout>
    );
}
